@@ -10,6 +10,8 @@ use Mojolicious::Plugin::Webpack;
 
 use constant DEBUG => $ENV{MOJO_WEBPACK_DEBUG} ? 1 : 0;
 
+our $VERSION = $Mojolicious::Plugin::Webpack::VERSION || '0.01';
+
 has dependencies => sub {
   return {
     core => [qw(webpack webpack-cli webpack-plugin-hash-output html-webpack-plugin)],
@@ -55,7 +57,6 @@ sub register {
 
   $self->_install_node_deps;
   $self->_run_webpack($app);
-  $self->_install_shim($app) if $config->{shim};
 }
 
 sub _binary {
@@ -63,7 +64,7 @@ sub _binary {
   my $config_file = $self->{files}{'webpack.config.js'}[1];
 
   return
-      $ENV{MOJO_WEBPACK_BINARY} ? $ENV{MOJO_WEBPACK_BINARY}
+      $ENV{MOJO_WEBPACK_BINARY}    ? $ENV{MOJO_WEBPACK_BINARY}
     : $config_file =~ /\brollup\./ ? path($config_file->dirname, qw(node_modules .bin rollup))->to_string
     :                                path($config_file->dirname, qw(node_modules .bin webpack))->to_string;
 }
@@ -100,41 +101,6 @@ sub _install_node_deps {
   return $n;
 }
 
-sub _install_shim {
-  my ($self, $app) = @_;
-  my $shim_class = sprintf '%s::Plugin::Webpack', ref $app;
-  my $shim_file  = path(Mojo::Util::class_to_path($shim_class));
-  my $record     = 1;
-  my $source     = '';
-
-  return $shim_file if Mojolicious::Plugin::Webpack->VERSION eq ($shim_class->VERSION // '');
-  return $shim_file if !-w $shim_file->dirname;
-
-  my $SOURCE = path($INC{Mojo::Util::class_to_path('Mojolicious::Plugin::Webpack')})->open('<');
-  while (<$SOURCE>) {
-    s/package Mojolicious::Plugin::Webpack;/package $shim_class;/;
-    s/^Mojolicious::Plugin::Webpack\s-/$shim_class -/;
-
-    if (/\{MOJO_WEBPACK_BUILD\}/) {
-      next;
-    }
-    elsif (/^=head1 SYNOPSIS/) {
-      $record = 0;
-      $source .= "=head1 SYNOPSIS\n\nSee L<Mojolicious::Plugin::Webpack>.\n\n";
-    }
-    elsif (/^=head1 MIGRATING FROM ASSETPACK/) {
-      $record = 0;
-    }
-    elsif (!$record and /^=head1/) {
-      $record = 1;
-    }
-
-    $source .= $_ if $record;
-  }
-
-  return $shim_file->spurt($source);
-}
-
 sub _migrate_from_assetpack {
   my $self = shift;
 
@@ -210,15 +176,13 @@ sub _render_to_file {
     /Autogenerated\s*by\s*Mojolicious-Plugin-Webpack/i and $is_generated = $_ while <$CFG>;
   };
 
-  state $VERSION = $Mojolicious::Plugin::Webpack::VERSION;
-
   return $self->{files}{$name} = [custom  => $out_file] if !$is_generated and -r $out_file;
   return $self->{files}{$name} = [current => $out_file] if $is_generated =~ /\b$VERSION\b/;
 
   my $template = $self->_share_dir->child($name)->slurp;
   $template =~ s!__AUTOGENERATED__!Autogenerated by Mojolicious-Plugin-Webpack $VERSION!g;
   $template =~ s!__NAME__!{$app->moniker}!ge;
-  $template =~ s!__VERSION__!{$app->VERSION || '0.0.1'}!ge;
+  $template =~ s!__VERSION__!{_semver($app->VERSION)}!ge;
   $out_file->spurt($template);
   return $self->{files}{$name} = [generated => $out_file];
 }
@@ -251,6 +215,13 @@ sub _run_webpack {
   die "[Webpack] $run_with @cmd: $!" if $!;
 }
 
+sub _semver {
+  my @v = split /\./, shift // '';
+  push @v, '0', while @v < 2;
+  push @v, '1' if @v < 3;
+  return join '.', @v;
+}
+
 sub _webpack_environment {
   my $self = shift;
   my %env  = %ENV;
@@ -268,7 +239,7 @@ sub _webpack_environment {
 package    # hide from pause
   Mojolicious::Plugin::Webpack::CWD;
 
-sub new { _chdir(bless([$_[2] || Mojo::File->new->to_string], $_[0]), $_[1]) }
+sub new     { _chdir(bless([$_[2] || Mojo::File->new->to_string], $_[0]), $_[1]) }
 sub _chdir  { chdir $_[1] or die "[Webpack] chdir $_[1]: $!"; $_[0] }
 sub DESTROY { $_[0]->_chdir($_[0]->[0]) }
 
@@ -323,43 +294,6 @@ want C<npm install> to be run again.
 Set this variable to pass on C<--progress>, C<--profile> and C<--verbose> to
 "webpack".
 
-=head1 PLUGIN SHIM
-
-L<Mojolicious::Plugin::Webpack::Builder> will install a shim of
-L<Mojolicious::Plugin::Webpack> if there is a writable "Plugin" directory in
-your distribution. Example:
-
-  # Generate a full Mojolicious application
-  $ mojo generate app MyApp
-  $ cd my_app
-
-  # Create a Plugin directory
-  $ mkdir -p lib/MyApp/Plugin
-
-  # Edit your application and enable it to load the shim
-  $ $EDITOR lib/MyApp.pm
-
-When editing C<MyApp.pm>, add load the L<Mojolicious::Plugin::Webpack> plugin
-with the "shim" key set:
-
-  sub startup {
-    my $self = shift;
-
-    # Make sure you can load plugins from your application namespaces
-    unshift @{$self->plugins->namespaces}, "MyApp::Plugin";
-
-    # Load the plugin with "shim" set
-    $self->plugin(Webpack => {process => ["js"], shim => 1});
-  }
-
-Save the file and start your application with C<mojo webpack>:
-
-  $ mojo webpack ./script/my_app
-
-This will then generate C<lib/MyApp/Plugin/Webpack.pm> which will be enough to
-run in production, which again means that your application does not depend on
-L<Mojolicious::Plugin::Webpack> at all.
-
 =head1 ATTRIBUTES
 
 =head2 dependencies
